🔸BIOMASS — PolSARtools 0.11 documentation

Skip to main content
`Ctrl`+`K`

# 🔸BIOMASS

## L1-A (`import_biomass_l1a`)

The import_biomass_l1a function extracts matrix elements (S2/C4/T4/C3/T3/C2/T2) from the given BIOMASS L1-A folder and saves them into respective directories.

polsartools.import_biomass_l1a(in_dir, mat='T3', azlks=8, rglks=2, fmt='tif', cog=False, ovr=[2, 4, 8, 16], comp=False, bsc='sigma0', out_dir=None, recip=False, geocode=False)

  Extract polarimetric S2/T4/C4/T3/C3 matrix data from BIOMASS L1A SLC data.

  ### Example Usage:

  To process imagery and generate a T3 matrix:

      import_biomass_l1a("/path/to/data", mat="T3")

  To process imagery and generate a C3 matrix:

      import_biomass_l1a("/path/to/data", mat="C3", azlks=10, rglks=3)

  ### Parameters:

  in_dirstr

    Path to the folder containing the BIOMASS L1A files.

  matstr, optional (default=’T3’)

    Type of matrix to extract. Valid options: ‘S2’, ‘C4, ‘C3’, ‘T4’, ‘T3’, ‘C2HX’, ‘C2VX’, ‘C2HV’,’T2HV’

  azlksint, optional (default=8)

    The number of azimuth looks to apply during the C/T processing.

  rglksint, optional (default=2)

    The number of range looks to apply during the C/Tprocessing.

  fmt{‘tif’, ‘bin’}, optional (default=’tif’)

    Output format: - ‘tif’: GeoTIFF - ‘bin’: Raw binary format

  cogbool, optional (default=False)

    If True, outputs will be saved as Cloud Optimized GeoTIFFs with internal tiling and overviews.

  ovrlist of int, optional (default=[2, 4, 8, 16])

    Overview levels for COG generation. Ignored if cog=False.

  compbool, optional (default=False)

    If True, applies LZW compression to GeoTIFF outputs.

  bscstr, optional (default=’sigma0’)

    The type of radar cross-section to use for scaling. Available options:

    - ‘sigma0’ : Uses sigmaNought LUT for scaling.

    - ‘gamma0’ : Uses gammaNought LUT for scaling.

  out_dirstr or None, optional (default=None)

    Directory to save output files. If None, a folder named after the matrix type will be created in the same location as the input file.

  recipbool, optional (default=False)

    If True, scattering matrix reciprocal symmetry is applied, i.e, S_HV = S_VH.

## L1-B (`import_biomass_l1b`)

The import_biomass_l1b function extracts intensity elements (HH,HV,VH,VV; sigma0 or gamma0) from the given L1B folder and saves them into a II directory.

polsartools.import_biomass_l1b(in_dir, fmt='tif', cog=False, ovr=[2, 4, 8, 16], comp=False, bsc='sigma0', out_dir=None, geocode=True)

  Extracts the backscatter intensity elements from a BIOMASS L2B ‘_DGM__’ folder and saves them into respective tif/binar files.

  ### Example Usage:

  The following code will extract the intensity elements from a BIOMASS L2B ‘_DGM__’ folder

      import_biomass_l1b("/path/to/data")

  ### Parameters:

  in_dirstr

    Path to the folder containing the BIOMASS L1B files.

  fmt{‘tif’, ‘bin’}, optional (default=’tif’)

    Output format: - ‘tif’: GeoTIFF - ‘bin’: Raw binary format

  cogbool, optional (default=False)

    If True, outputs will be saved as Cloud Optimized GeoTIFFs with internal tiling and overviews.

  ovrlist of int, optional (default=[2, 4, 8, 16])

    Overview levels for COG generation. Ignored if cog=False.

  compbool, optional (default=False)

    If True, applies LZW compression to GeoTIFF outputs.

  bscstr, optional (default=’sigma0’)

    The type of radar cross-section to use for scaling. Available options:

    - ‘sigma0’ : Uses sigmaNought LUT for scaling.

    - ‘gamma0’ : Uses gammaNought LUT for scaling.

  out_dirstr or None, optional (default=None)

    Directory to save output files. If None, a folder named after the matrix type will be created in the same location as the input file.

  geocodebool, default=True

    If True, performs a coarse geocoding using GCPs in the file.